<!DOCTYPE html><html lang="en"><head>
    <meta charset="utf-8">
    <meta name="generator" content="Polymer Starter Kit">
    <meta name="viewport" content="width=device-width,minimum-scale=1,initial-scale=1,user-scalable=yes">

    <title>Hedgehog RMD {{ version }}</title>
    <meta name="description" content="Remote monitoring and diagnostic appication for Hedgehog measurement system.">

    <link rel="icon" href="/images/favicon.ico">


    <link rel="manifest" href="/manifest.json">


    <meta name="theme-color" content="#3f51b5">


    <meta name="mobile-web-app-capable" content="yes">
    <meta name="application-name" content="Hedgehog RMD">


    <meta name="apple-mobile-web-app-capable" content="yes">
    <meta name="apple-mobile-web-app-status-bar-style" content="black-translucent">
    <meta name="apple-mobile-web-app-title" content="My App">


    <link rel="apple-touch-icon" href="/images/manifest/icon-48x48.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/manifest/icon-72x72.png">
    <link rel="apple-touch-icon" sizes="96x96" href="/images/manifest/icon-96x96.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/manifest/icon-144x144.png">
    <link rel="apple-touch-icon" sizes="192x192" href="/images/manifest/icon-192x192.png">


    <meta name="msapplication-TileImage" content="/images/manifest/icon-144x144.png">
    <meta name="msapplication-TileColor" content="#3f51b5">
    <meta name="msapplication-tap-highlight" content="no">

    {% load static %}

    <script>window.Polymer={dom:"shadow",lazyRegister:!0},function(){"use strict";var e=function(){window.HTMLImports||document.dispatchEvent(new CustomEvent("WebComponentsReady",{bubbles:!0}))};if("registerElement"in document&&"import"in document.createElement("link")&&"content"in document.createElement("template"))e();else{var n=document.createElement("script");n.async=!0,n.src="{% static webcomponents %}",n.onload=e,document.head.appendChild(n)}}(),"serviceWorker"in navigator&&window.addEventListener("load",function(){navigator.serviceWorker.register("{% static service_worker %}")});</script>

    <link rel="import" href="{% static shell %}">

    <style>
        body {
            margin: 0;
            font-family: 'Roboto', 'Noto', sans-serif;
            line-height: 1.5;
            min-height: 100vh;
            background-color: #eeeeee;
        }

    </style>
</head>
<body>
    <hedgehog-app version="{{ version }}"
            repository-api-url="http://localhost:8080" engine-api-url="http://localhost:8080" broker-api-url="http://localhost:8080" live-api-url="ws://localhost:8080" auto-refresh-interval="3000" verbose="">
    </hedgehog-app>
</body></html>